@@ -168,6 +168,8 @@ import jsii
 import publication
 import typing_extensions
 
+from typeguard import check_type
+
 from ._jsii import *
 
 import aws_cdk.aws_cloudwatch
@@ -188,14 +190,14 @@ class S3ToStepfunctions(
         scope: constructs.Construct,
         id: builtins.str,
         *,
-        state_machine_props: aws_cdk.aws_stepfunctions.StateMachineProps,
-        bucket_props: typing.Optional[aws_cdk.aws_s3.BucketProps] = None,
+        state_machine_props: typing.Union[aws_cdk.aws_stepfunctions.StateMachineProps, typing.Dict[str, typing.Any]],
+        bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
         create_cloud_watch_alarms: typing.Optional[builtins.bool] = None,
         deploy_cloud_trail: typing.Optional[builtins.bool] = None,
-        event_rule_props: typing.Optional[aws_cdk.aws_events.RuleProps] = None,
+        event_rule_props: typing.Optional[typing.Union[aws_cdk.aws_events.RuleProps, typing.Dict[str, typing.Any]]] = None,
         existing_bucket_obj: typing.Optional[aws_cdk.aws_s3.IBucket] = None,
-        logging_bucket_props: typing.Optional[aws_cdk.aws_s3.BucketProps] = None,
-        log_group_props: typing.Optional[aws_cdk.aws_logs.LogGroupProps] = None,
+        logging_bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
+        log_group_props: typing.Optional[typing.Union[aws_cdk.aws_logs.LogGroupProps, typing.Dict[str, typing.Any]]] = None,
         log_s3_access_logs: typing.Optional[builtins.bool] = None,
     ) -> None:
         '''
@@ -214,6 +216,10 @@ class S3ToStepfunctions(
         :access: public
         :summary: Constructs a new instance of the S3ToStepfunctions class.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(S3ToStepfunctions.__init__)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = S3ToStepfunctionsProps(
             state_machine_props=state_machine_props,
             bucket_props=bucket_props,
@@ -228,34 +234,34 @@ class S3ToStepfunctions(
 
         jsii.create(self.__class__, self, [scope, id, props])
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="s3BucketInterface")
     def s3_bucket_interface(self) -> aws_cdk.aws_s3.IBucket:
         return typing.cast(aws_cdk.aws_s3.IBucket, jsii.get(self, "s3BucketInterface"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="stateMachine")
     def state_machine(self) -> aws_cdk.aws_stepfunctions.StateMachine:
         return typing.cast(aws_cdk.aws_stepfunctions.StateMachine, jsii.get(self, "stateMachine"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="stateMachineLogGroup")
     def state_machine_log_group(self) -> aws_cdk.aws_logs.ILogGroup:
         return typing.cast(aws_cdk.aws_logs.ILogGroup, jsii.get(self, "stateMachineLogGroup"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="cloudwatchAlarms")
     def cloudwatch_alarms(
         self,
     ) -> typing.Optional[typing.List[aws_cdk.aws_cloudwatch.Alarm]]:
         return typing.cast(typing.Optional[typing.List[aws_cdk.aws_cloudwatch.Alarm]], jsii.get(self, "cloudwatchAlarms"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="s3Bucket")
     def s3_bucket(self) -> typing.Optional[aws_cdk.aws_s3.Bucket]:
         return typing.cast(typing.Optional[aws_cdk.aws_s3.Bucket], jsii.get(self, "s3Bucket"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="s3LoggingBucket")
     def s3_logging_bucket(self) -> typing.Optional[aws_cdk.aws_s3.Bucket]:
         return typing.cast(typing.Optional[aws_cdk.aws_s3.Bucket], jsii.get(self, "s3LoggingBucket"))
@@ -280,14 +286,14 @@ class S3ToStepfunctionsProps:
     def __init__(
         self,
         *,
-        state_machine_props: aws_cdk.aws_stepfunctions.StateMachineProps,
-        bucket_props: typing.Optional[aws_cdk.aws_s3.BucketProps] = None,
+        state_machine_props: typing.Union[aws_cdk.aws_stepfunctions.StateMachineProps, typing.Dict[str, typing.Any]],
+        bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
         create_cloud_watch_alarms: typing.Optional[builtins.bool] = None,
         deploy_cloud_trail: typing.Optional[builtins.bool] = None,
-        event_rule_props: typing.Optional[aws_cdk.aws_events.RuleProps] = None,
+        event_rule_props: typing.Optional[typing.Union[aws_cdk.aws_events.RuleProps, typing.Dict[str, typing.Any]]] = None,
         existing_bucket_obj: typing.Optional[aws_cdk.aws_s3.IBucket] = None,
-        logging_bucket_props: typing.Optional[aws_cdk.aws_s3.BucketProps] = None,
-        log_group_props: typing.Optional[aws_cdk.aws_logs.LogGroupProps] = None,
+        logging_bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
+        log_group_props: typing.Optional[typing.Union[aws_cdk.aws_logs.LogGroupProps, typing.Dict[str, typing.Any]]] = None,
         log_s3_access_logs: typing.Optional[builtins.bool] = None,
     ) -> None:
         '''
@@ -304,15 +310,26 @@ class S3ToStepfunctionsProps:
         :summary: The properties for the S3ToStepfunctions Construct
         '''
         if isinstance(state_machine_props, dict):
-            state_machine_props = aws_cdk.aws_stepfunctions.StateMachineProps(**state_machine_props)
+            state_machine_props = StateMachineProps(**state_machine_props)
         if isinstance(bucket_props, dict):
-            bucket_props = aws_cdk.aws_s3.BucketProps(**bucket_props)
+            bucket_props = BucketProps(**bucket_props)
         if isinstance(event_rule_props, dict):
-            event_rule_props = aws_cdk.aws_events.RuleProps(**event_rule_props)
+            event_rule_props = RuleProps(**event_rule_props)
         if isinstance(logging_bucket_props, dict):
-            logging_bucket_props = aws_cdk.aws_s3.BucketProps(**logging_bucket_props)
+            logging_bucket_props = BucketProps(**logging_bucket_props)
         if isinstance(log_group_props, dict):
-            log_group_props = aws_cdk.aws_logs.LogGroupProps(**log_group_props)
+            log_group_props = LogGroupProps(**log_group_props)
+        if __debug__:
+            type_hints = typing.get_type_hints(S3ToStepfunctionsProps.__init__)
+            check_type(argname="argument state_machine_props", value=state_machine_props, expected_type=type_hints["state_machine_props"])
+            check_type(argname="argument bucket_props", value=bucket_props, expected_type=type_hints["bucket_props"])
+            check_type(argname="argument create_cloud_watch_alarms", value=create_cloud_watch_alarms, expected_type=type_hints["create_cloud_watch_alarms"])
+            check_type(argname="argument deploy_cloud_trail", value=deploy_cloud_trail, expected_type=type_hints["deploy_cloud_trail"])
+            check_type(argname="argument event_rule_props", value=event_rule_props, expected_type=type_hints["event_rule_props"])
+            check_type(argname="argument existing_bucket_obj", value=existing_bucket_obj, expected_type=type_hints["existing_bucket_obj"])
+            check_type(argname="argument logging_bucket_props", value=logging_bucket_props, expected_type=type_hints["logging_bucket_props"])
+            check_type(argname="argument log_group_props", value=log_group_props, expected_type=type_hints["log_group_props"])
+            check_type(argname="argument log_s3_access_logs", value=log_s3_access_logs, expected_type=type_hints["log_s3_access_logs"])
         self._values: typing.Dict[str, typing.Any] = {
             "state_machine_props": state_machine_props,
         }
